@@ -33,6 +33,7 @@
 
 class demodulator;
 class sourceDecoder;
+class ftpInterface;
 
 extern int input_samples_buffer_request;
 extern int symbols_per_frame_list[4];
@@ -72,6 +73,7 @@ extern float channel_transfer_function_buffer[82980]; /* complex */
 extern int transmission_frame_buffer_wptr;
 extern int lFAC;
 extern float cpsd[513], psd[513];
+extern bool drmBusy;
 
 //Display * display;
 extern int runstate;
@@ -89,6 +91,7 @@ extern struct dfltMOTobj default_MOT_object;
 extern int channel_decoded_data_buffer_data_valid;
 extern double channel_decoded_data_buffer[110000];
 extern float WMERFAC;
+
 extern bool callsignValid;
 
 
@@ -119,12 +122,11 @@ extern uint txTransportID;
 extern bool stopDRM;
 extern float avgSNR;
 extern float lastAvgSNR;
+extern bool avgSNRAvailable;
 extern sourceDecoder *srcDecoder;
 extern QString drmCallsign;
 
 
-
-
 #endif
 
 
