@@ -20,13 +20,12 @@ class logBook
 public:
   enum eIndex {LPROG,LVER,LDATE,LTIME,LENDTIME,LCALL,LFREQ,LMODE,LTX,LRX,LNAME,LQTH,LSTATE,LPROV,LCNTRY,LLOC,LSO,LSI,LFREE,LNOTES,LPWR};
   logBook();
-  void logQSO(QString call,QString comment);
+  void logQSO(QString call, QString mode, QString comment);
 private:
   void getFrequency();
   double frequency;
   void setParam(eIndex tag,QString value);
   ipcMessage *ipcQueue;
-
 };
 
 #endif // LOGBOOK_H
