@@ -4,7 +4,7 @@
 #include <QThread>
 #include "appdefs.h"
 #include "sstv/syncprocessor.h"
-#include "utils/buffermanag.h"
+#include "buffermanag.h"
 
 
 
@@ -23,8 +23,8 @@ public:
   enum erxState {RXIDLE,RXRUNNING,RXRESTART,RXINIT};
   explicit rxFunctions(QObject *parent = 0);
   ~rxFunctions();
-  void init();
   void run();
+  void init();
   void stopAndWait();
   void startRX();
   void restartRX();
@@ -32,8 +32,7 @@ public:
   QString getModeStr();
   sstvRx  *sstvRxPtr;
   void stopThread();
-
-
+  bool rxBusy();
 
 #ifndef QT_NO_DEBUG
   unsigned int setOffset(unsigned int offset,bool ask);
@@ -45,6 +44,7 @@ private:
   erxState rxState;
   void switchRxState(erxState newState);
   uint rxBytes;
+  void forceInit();
 
 };
 
