@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2000-2012 by Johan Maes                                 *
+*   Copyright (C) 2000-2019 by Johan Maes                                 *
 *   on4qz@telenet.be                                                      *
 *   http://users.telenet.be/on4qz                                         *
 *                                                                         *
@@ -20,7 +20,6 @@
 ***************************************************************************/
 #include "rigcontrol.h"
 #include "appglobal.h"
-#include <QMessageBox>
 #include <QSplashScreen>
 #include <QApplication>
 #include <sys/ioctl.h>
@@ -29,6 +28,8 @@
 #include "mainwindow.h"
 #include <QMessageBox>
 #include "txwidget.h"
+#include "configparams.h"
+#include "dispatcher.h"
 
 
 #define MAXCONFLEN 128
@@ -68,12 +69,11 @@ bool rigControl::init()
   int retcode;
   if(!catParams.enableCAT) return false;
 
-  addToLog(QString("rigcontrol:init myport pathname: %1").arg(myport.pathname),LOGRIGCTRL);
   catParams.radioModelNumber=getModelNumber(getRadioModelIndex());
   my_rig = rig_init(catParams.radioModelNumber);
   if(!my_rig)
     {
-      addToLog(QString("Error in connection using radio model %1").arg(catParams.radioModel),LOGALL);
+      addToLogDebug(QString("Error in connection using radio model %1").arg(catParams.radioModel),LOGALL);
       initError=QString("Error in connection using radio model %1").arg(catParams.radioModel);
       return false;
     }
@@ -85,9 +85,11 @@ bool rigControl::init()
           rig_set_conf(my_rig, rig_token_lookup(my_rig, "civaddr"), catParams.civAddress.toLatin1());
         }
     }
-
-  strncpy(my_rig->state.rigport.pathname,(const char *)catParams.serialPort.toLatin1().data(),FILPATHLEN);
-  strncpy(my_rig->state.pttport.pathname,(const char *)catParams.serialPort.toLatin1().data(),FILPATHLEN);
+  if(!catParams.serialPort.isEmpty())
+     {
+      strncpy(my_rig->state.rigport.pathname,(const char *)catParams.serialPort.toLatin1().data(),FILPATHLEN);
+    }
+//  strncpy(my_rig->state.pttport.pathname,(const char *)catParams.serialPort.toLatin1().data(),FILPATHLEN);
   my_rig->state.rigport.parm.serial.rate = catParams.baudrate;
   my_rig->state.rigport.parm.serial.data_bits=catParams.databits;
   my_rig->state.rigport.parm.serial.stop_bits=catParams.stopbits;
@@ -103,16 +105,28 @@ bool rigControl::init()
   retcode = rig_open(my_rig);
   if (retcode != RIG_OK )
     {
-      addToLog(QString("CAT Error: %1").arg(QString(rigerror(retcode))),LOGALL);
+      addToLogDebug(QString("CAT Error: %1").arg(QString(rigerror(retcode))),LOGALL);
       initError=QString("CAT Error: %1").arg(QString(rigerror(retcode)));
       return false;
     }
   addToLog("rigcontroller successfully opened",LOGRIGCTRL);
   rigControlEnabled=true;
+
+
+
   // int verbose=0;
   // rig_set_debug(verbose<2 ? RIG_DEBUG_NONE: (rig_debug_level_e)verbose);
   // rig_debug(RIG_DEBUG_VERBOSE, "rigctl, %s\n", hamlib_version);
   // test if we can contact the tranceiver
+
+  canSetFreq=(my_rig->caps->set_freq != NULL);
+  canGetFreq=(my_rig->caps->get_freq != NULL);
+  canSetMode=(my_rig->caps->set_mode != NULL);
+  canGetMode=(my_rig->caps->get_mode != NULL);
+  canSetPTT=(my_rig->caps->set_ptt != NULL);
+  canGetPTT=(my_rig->caps->get_ptt != NULL);
+
+
   double fr;
   if(!getFrequency(fr))
     {
@@ -127,34 +141,47 @@ bool rigControl::getFrequency(double &frequency)
   if(catParams.enableXMLRPC)
     {
       frequency=xmlIntfPtr->getFrequency();
+      return true;
     }
-  else
-    {
-      if(!rigControlEnabled) return false;
-      retcode = rig_get_freq(my_rig, RIG_VFO_CURR, &frequency);
-      if (retcode != RIG_OK )
-        frequency=lastFrequency;
-      //    {errorMessage(retcode,"getFrequency"); return false; }
-    }
-  return true;
+
+  if(!rigControlEnabled || !canGetFreq) return false;
+  retcode = rig_get_freq(my_rig, RIG_VFO_CURR, &frequency);
+    for(int i=0;i<RIGCMDTRIES;i++)
+      {
+        retcode = rig_get_freq(my_rig, RIG_VFO_CURR, &frequency);
+        if (retcode==RIG_OK)
+          {
+            return true;
+          }
+      }
+//  errorMessage(retcode,"getFrequency");
+  frequency=lastFrequency;
+  return false;
+
 }
 
 bool rigControl::setFrequency(double frequency)
 {
-  int retcode;
+  int retcode=-1;
   if(catParams.enableXMLRPC)
     {
       xmlIntfPtr->setFrequency(frequency);
+      return true;
     }
-  else
+  if(!rigControlEnabled || !canSetFreq) return false;
+  //        retcode = rig_set_vfo(my_rig, RIG_VFO_CURR);
+  //        if (retcode != RIG_OK ) {errorMessage(retcode,"setVFO"); return false; }
+
+  for(int i=0;i<RIGCMDTRIES;i++)
     {
-      if(!rigControlEnabled) return false;
-      retcode = rig_set_vfo(my_rig, RIG_VFO_CURR);
-      if (retcode != RIG_OK ) {errorMessage(retcode,"setVFO"); return false; }
       retcode = rig_set_freq(my_rig, RIG_VFO_CURR, frequency);
-      if (retcode != RIG_OK ) {errorMessage(retcode,"setFrequency"); return false; }
+      if (retcode==RIG_OK)
+        {
+          return true;
+        }
     }
-  return true;
+  errorMessage(retcode,"setFrequency");
+  return false;
 }
 
 void rigControl::disable()
@@ -172,30 +199,40 @@ bool rigControl::getMode(QString &mode)
   if(catParams.enableXMLRPC)
     {
       mode =xmlIntfPtr->getMode();
+      return true;
     }
-  else
+
+  rmode_t rmode;
+  pbwidth_t width;
+  int retcode;
+  if(!rigControlEnabled || !canGetMode) return false;
+
+  for(int i=0;i<RIGCMDTRIES;i++)
     {
-      rmode_t rmode;
-      pbwidth_t width;
-      int retcode;
-      if(!rigControlEnabled) return false;
       retcode = rig_get_mode(my_rig, RIG_VFO_CURR, &rmode, &width);
-      if (retcode != RIG_OK ) {errorMessage(retcode,"getMode"); return false; }
-      mode=QString(rig_strrmode(rmode));
+      if (retcode==RIG_OK)
+        {
+          mode=QString(rig_strrmode(rmode));
+          return true;
+        }
     }
-  return true;
+  errorMessage(retcode,"getMode");
+  return false;
+
+
 }
 
-bool rigControl::setMode(QString mode)
+bool rigControl::setMode(QString mode,QString passBand)
 {
   QString orgMode;
+  int pb;
   int i;
   int pos=-1;
   if(catParams.enableXMLRPC)
     {
       orgMode=xmlIntfPtr->getMode();
       for(i=0;i<xmlModes.count();i++)
-       {
+        {
           pos=orgMode.indexOf(xmlModes.at(i),Qt::CaseInsensitive);
           if(pos>=0)
             {
@@ -204,16 +241,36 @@ bool rigControl::setMode(QString mode)
             }
         }
       if(pos>=0) xmlIntfPtr->setMode(orgMode);
+      return true;
+    }
+
+  rmode_t rmode=rig_parse_mode(mode.toLatin1().data());
+  if(passBand=="Narrow")
+    {
+      pb=rig_passband_narrow(my_rig,rmode);
+    }
+  else if(passBand=="Wide")
+    {
+      pb=rig_passband_wide(my_rig,rmode);
     }
   else
     {
-      rmode_t rmode=rig_parse_mode(mode.toLatin1().data());
-      int retcode;
-      if(!rigControlEnabled) return false;
-      retcode = rig_set_mode(my_rig, RIG_VFO_CURR, rmode, rig_passband_normal(my_rig,rmode));
-      if (retcode != RIG_OK ) {errorMessage(retcode,"setMode"); return false; }
+      pb=rig_passband_normal(my_rig,rmode);
     }
-  return true;
+  int retcode;
+  if(!rigControlEnabled || !canSetMode) return false;
+
+  for(int i=0;i<RIGCMDTRIES;i++)
+    {
+      retcode = rig_set_mode(my_rig, RIG_VFO_CURR, rmode, pb);
+      if (retcode==RIG_OK)
+        {
+          mode=QString(rig_strrmode(rmode));
+          return true;
+        }
+    }
+  errorMessage(retcode,"setMode");
+  return false;
 }
 
 
@@ -221,18 +278,31 @@ bool rigControl::setPTT(bool on)
 {
   int retcode;
   ptt_t ptt;
-  if(on) ptt=RIG_PTT_ON; else ptt=RIG_PTT_OFF;
-  if(!rigControlEnabled) return false;
-  retcode = rig_set_ptt (my_rig, RIG_VFO_CURR,ptt);
-  if (retcode != RIG_OK ) {errorMessage(retcode,"setPTT"); return false; }
-  return true;
+  /* Hamlib will fall back to RIG_PTT_ON if RIG_PTT_ON_DATA is not available in current hamlib configuration */
+  if(on) ptt=RIG_PTT_ON_DATA; else ptt=RIG_PTT_OFF;
+  if(!rigControlEnabled || !canSetPTT) return false;
+
+  for(int i=0;i<RIGCMDTRIES;i++)
+    {
+      retcode = rig_set_ptt (my_rig, RIG_VFO_CURR,ptt);
+      if (retcode==RIG_OK)
+        {
+          return true;
+        }
+    }
+  errorMessage(retcode,"setPTT");
+  return false;
 }
 
 
 
 void  rigControl::errorMessage(int errorCode,QString command)
 {
-  QMessageBox::information(0,"Cat interface",QString("Error in connection: %1\n%2").arg(QString(rigerror(errorCode))).arg(command));
+  displayMBoxEvent *stmb;
+  stmb= new displayMBoxEvent("Cat interface",QString("Error in connection: %1\n%2").arg(QString(rigerror(errorCode))).arg(command));
+  QApplication::postEvent( dispatcherPtr, stmb );
+
+//  QMessageBox::information(0,"Cat interface",QString("Error in connection: %1\n%2").arg(QString(rigerror(errorCode))).arg(command));
 }
 
 void rigControl::getRadioList()
@@ -242,7 +312,7 @@ void rigControl::getRadioList()
       capsList.clear();
       rig_load_all_backends();
       rig_list_foreach(collect,0);
-      qSort(capsList.begin(),capsList.end(),model_Sort);
+      std::sort(capsList.begin(),capsList.end(),model_Sort);
       radiolistLoaded=true;
     }
 }
@@ -373,11 +443,43 @@ void rigControl::activatePTT(bool b)
 
 int  rigControl::rawCommand(QByteArray ba)
 {
+  int i;
+  bool result;
+  char rxBuffer[100];
+
+  QString command="w ";
+  QByteArray cmdBa;
   if(!rigControlEnabled) return 0;
   struct rig_state *rs;
   rs = &my_rig->state;
+  // check if backend via rigctld
+  if(catParams.radioModelNumber==2)
+    {
+      // we need to send this as a command string
+      if(additionalCommandHex)
+        {
+          for(i=0;i<ba.count();i++)
+            {
 
-  //	serial_flush(&rs->rigport);
+              command+="\\0x";
+              command+=QString::number((unsigned char)ba.at(i),16);
+            }
+        }
+      else
+        {
+          command+=ba;
+        }
+
+      command+="\n";
+      cmdBa=command.toLatin1();
+      result=write_block(&rs->rigport,cmdBa.constData(), cmdBa.count());
+
+    }
+  else
+    {
+      result=write_block(&rs->rigport,ba.constData(), ba.count());
+    }
+  read_block(&rs->rigport,rxBuffer,99);
+  return result;
 
-  return write_block(&rs->rigport,ba.constData(), ba.count());
 }
