@@ -11,12 +11,11 @@
 #include <QPainter>
 #include <QDebug>
 
-#define FREQ_AMPLITUDE 16E3
-#define FREQ_OFFSET 350.0
+//#define FREQ_AMPLITUDE 16E3
+#define FREQ_AMPLITUDE 6E3
+#define FREQ_OFFSET 300.0
 #define FREQ_MAX 2600.
 
-//#define FONTSIZE 13
-//#define FONTNAME "Arial"
 
 waterfallText::waterfallText()
 {
@@ -25,13 +24,8 @@ waterfallText::waterfallText()
   dataBuffer=NULL;
   txFilter=NULL;
   phr=phi=NULL;
-
 }
 
-/**
-  \todo:: txFilter not used
- */
-
 waterfallText::~waterfallText()
 {
   fftw_destroy_plan(plan);
@@ -40,7 +34,6 @@ waterfallText::~waterfallText()
   if(dataBuffer) fftw_free(dataBuffer);
 }
 
-
 void waterfallText::init()
 {
   int i;
@@ -148,7 +141,8 @@ void waterfallText::setupImage(QString txt)
   image.fill(Qt::black);
   p.begin(&image);
   p.setPen(pen);
-  p.setFont(QFont(wfFont,wfFontSize,QFont::Light));
+  if(wfBold) p.setFont(QFont(wfFont,wfFontSize,QFont::Bold));
+  else p.setFont(QFont(wfFont,wfFontSize,QFont::Light));
   rct=p.boundingRect(QRect(0,0,imageWidth,30),Qt::AlignTop|Qt::AlignCenter,txt);
   p.end();
   height=rct.height();
@@ -157,7 +151,8 @@ void waterfallText::setupImage(QString txt)
   image.fill(Qt::black);
   p.begin(&image);
   p.setPen(pen);
-  p.setFont(QFont(wfFont,wfFontSize,QFont::Light));
+  if(wfBold) p.setFont(QFont(wfFont,wfFontSize,QFont::Bold));
+  else p.setFont(QFont(wfFont,wfFontSize,QFont::Light));
   p.drawText(QRectF(0,0,width,height),Qt::AlignCenter,txt);
   p.end();
   line=image.height();
@@ -169,6 +164,8 @@ QString  waterfallText::convert(QString txt)
   mexp.clear();
   mexp.addConversion('m',myCallsign);
   mexp.addConversion('s',QString::number(lastAvgSNR,'g',2));
+  mexp.addConversion('c',lastReceivedCall);
+
   QString t=mexp.convert(txt);
   return t;
 }
