@@ -1,27 +1,27 @@
 #ifndef WATERFALLTEXT_H
 #define WATERFALLTEXT_H
-#include "qsstvdefs.h"
-//#include <complex.h>
+#include "appdefs.h"
 #include "fftw3.h"
+#include "macroexpansion.h"
 #include <QString>
 #include <QImage>
-#include "utils/macroexpansion.h"
+
 
 class imageViewer;
-class filter;
+class wfFilter;
 
 
 class waterfallText
 {
 public:
   waterfallText();
-  ~ waterfallText();
+  ~waterfallText();
   void init();
   void setText(QString txt);
   QImage *getImagePtr() {return &image;}
  DSPFLOAT *nextLine();
  int getLength() {return fftLength;}
- double getDuration(QString txt=NULL);
+ double getDuration(QString txt=QString());
 private:
   int fftLength;
   int samplingrate;
@@ -37,7 +37,7 @@ private:
   int width;
   int height;
   int line;
-  filter *txFilter;
+  wfFilter *txFilter;
   QImage image;
   int dLine;
   int startFreqIndex;
