@@ -15,11 +15,10 @@ class extViewer : public QDialog
 public:
   explicit extViewer(QWidget *parent = 0);
   ~extViewer();
-  void setup(QImage im, QString fn);
+  void setup(QString fn);
   
 private:
   Ui::extViewer *ui;
-  void paintEvent ( QPaintEvent * );
   int w,h;
   int labelWidth,labelHeight;
   QString fileName;
